@@ -67,7 +67,7 @@ def get_eventhandling(eventid=None):
     elif eventid == "handlermodules":
         # TODO: We need to provide a dynamic list of event handlers
         res = ["UserNotification", "Token", "Federation", "Script", "Counter",
-               "RequestMangler", "ResponseMangler", "Logging"]
+               "RequestMangler", "ResponseMangler", "Logging", "CustomUserAttributes"]
     else:
         res = g.event_config.get_event(eventid)
     g.audit_object.log({"success": True})
