@@ -397,6 +397,11 @@ class TiQRTokenTestCase(MyApiTestCase):
         self.setUp_user_realms()
 
     def _test_create_token(self, user):
+        try:
+            # Try to remove the token, if it exists
+            remove_token("TIQR1")
+        except Exception:
+            pass
         pin = "test"
         token = init_token({"type": "tiqr",
                             "pin": pin,
@@ -428,8 +433,9 @@ class TiQRTokenTestCase(MyApiTestCase):
         r = token.create_challenge()
         self.assertEqual(r[0], True)
         self.assertEqual(r[1], _("Please scan the QR Code"))
-        self.assertTrue("img" in r[3], r[3])
-        self.assertTrue("value" in r[3], r[3])
+        self.assertTrue("img" in r[3]["attributes"], r[3])
+        self.assertTrue("image" in r[3], r[3])
+        self.assertTrue("value" in r[3]["attributes"], r[3])
 
     def _test_api_endpoint(self, user, expected_netloc):
         pin = "tiqr"
