@@ -43,7 +43,7 @@ class APIResolverTestCase(MyApiTestCase):
             res = self.app.full_dispatch_request()
             self.assertTrue(res.status_code == 200, res)
             self.assertTrue(res.json['result']['status'], res.json)
-            self.assertEquals(res.json['result']['value'], 1, res.json)
+            self.assertEqual(res.json['result']['value'], 1, res.json)
                     
         # check if the resolver was created
         with self.app.test_request_context('/resolver/',
